Re: [U-Boot] [PATCH v1 1/2] powerpc/85xx: rename NAND prefixes to CONFIG_SYS

2011-04-08 Thread Kumar Gala

On Apr 5, 2011, at 2:39 PM, Matthew McClintock wrote:

> renaming 85xx define CONFIG_NAND_OR_PRELIM to
> CONFIG_SYS_NAND_OR_PRELIM and CONFIG_NAND_BR_PRELIM to
> CONFIG_SYS_NAND_BR_PRELIM to use the more appropriate
> CONFIG_SYS prefix as well as be consistent with 83xx
> 
> Signed-off-by: Matthew McClintock 
> cc: Scott Wood 
> cc: Kumar Gala 
> ---
> arch/powerpc/cpu/mpc85xx/cpu_init_nand.c |8 
> include/configs/MPC8536DS.h  |   18 +-
> include/configs/MPC8569MDS.h |   12 ++--
> include/configs/MPC8572DS.h  |   18 +-
> include/configs/P1_P2_RDB.h  |   12 ++--
> include/configs/P2020DS.h|   14 +++---
> 6 files changed, 41 insertions(+), 41 deletions(-)

applied to 85xx

- k

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH v1 1/2] powerpc/85xx: rename NAND prefixes to CONFIG_SYS

2011-04-05 Thread Matthew McClintock
renaming 85xx define CONFIG_NAND_OR_PRELIM to
CONFIG_SYS_NAND_OR_PRELIM and CONFIG_NAND_BR_PRELIM to
CONFIG_SYS_NAND_BR_PRELIM to use the more appropriate
CONFIG_SYS prefix as well as be consistent with 83xx

Signed-off-by: Matthew McClintock 
cc: Scott Wood 
cc: Kumar Gala 
---
 arch/powerpc/cpu/mpc85xx/cpu_init_nand.c |8 
 include/configs/MPC8536DS.h  |   18 +-
 include/configs/MPC8569MDS.h |   12 ++--
 include/configs/MPC8572DS.h  |   18 +-
 include/configs/P1_P2_RDB.h  |   12 ++--
 include/configs/P2020DS.h|   14 +++---
 6 files changed, 41 insertions(+), 41 deletions(-)

diff --git a/include/configs/MPC8536DS.h b/include/configs/MPC8536DS.h
index 13300de..e915ee7 100644
--- a/include/configs/MPC8536DS.h
+++ b/include/configs/MPC8536DS.h
@@ -360,13 +360,13 @@
 #define CONFIG_SYS_NAND_U_BOOT_RELOC_SP ((CONFIG_SYS_INIT_L2_END - 1) & ~0xF)
 
 /* NAND flash config */
-#define CONFIG_NAND_BR_PRELIM \
+#define CONFIG_SYS_NAND_BR_PRELIM \
(BR_PHYS_ADDR(CONFIG_SYS_NAND_BASE_PHYS) \
| (2
diff --git a/arch/powerpc/cpu/mpc85xx/cpu_init_nand.c 
b/arch/powerpc/cpu/mpc85xx/cpu_init_nand.c
index 8fb27ab..920bb47 100644
--- a/arch/powerpc/cpu/mpc85xx/cpu_init_nand.c
+++ b/arch/powerpc/cpu/mpc85xx/cpu_init_nand.c
@@ -33,11 +33,11 @@ void cpu_init_f(void)
 */
out_be32(&lbc->lcrr, LCRR_DBYP | LCRR_CLKDIV_8);
 
-#if defined(CONFIG_NAND_BR_PRELIM) && defined(CONFIG_NAND_OR_PRELIM)
-   set_lbc_br(0, CONFIG_NAND_BR_PRELIM);
-   set_lbc_or(0, CONFIG_NAND_OR_PRELIM);
+#if defined(CONFIG_SYS_NAND_BR_PRELIM) && defined(CONFIG_SYS_NAND_OR_PRELIM)
+   set_lbc_br(0, CONFIG_SYS_NAND_BR_PRELIM);
+   set_lbc_or(0, CONFIG_SYS_NAND_OR_PRELIM);
 #else
 #error  CONFIG_NAND_BR_PRELIM, CONFIG_NAND_OR_PRELIM must be defined
 #endif
 
 #if defined(CONFIG_SYS_RAMBOOT) && defined(CONFIG_SYS_INIT_L2_ADDR)
@@ -33,11 +33,11 @@ void cpu_init_f(void)
 #else
-#error  CONFIG_NAND_BR_PRELIM, CONFIG_NAND_OR_PRELIM must be defined
+#error  CONFIG_SYS_NAND_BR_PRELIM, CONFIG_SYS_NAND_OR_PRELIM must be defined
 #endif
 